@@ -15,7 +15,7 @@
  *
  * Authored by: Thomas Voß <thomas.voss@canonical.com>
  */
-#include "com/ubuntu/location/default_permission_manager.h"
+#include <com/ubuntu/location/default_permission_manager.h>
 
 namespace cul = com::ubuntu::location;
 
